#
# spec file for package duplicity
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?python_sitelib:  %global python_sitelib  %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
Name:           duplicity
Version:        0.7.10
Release:        1.1
Summary:        Encrypted bandwidth-efficient backup using the rsync algorithm
License:        GPL-3.0+
Group:          Productivity/Archiving/Backup
Url:            http://duplicity.nongnu.org/
Source:         https://code.launchpad.net/%{name}/0.7-series/%{version}/+download/%{name}-%{version}.tar.gz
Source99:       duplicity-rpmlintrc
Patch1:         duplicity-remove_shebang.patch
BuildRequires:  python-devel
BuildRequires:  python-setuptools
Requires:       gpg
Recommends:     lftp
Requires:       python-lockfile
Recommends:     python-boto
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1210
BuildRequires:  librsync-devel >= 0.9.6
%else
BuildRequires:  librsync >= 0.9.6
%endif

%description
Duplicity incrementally backs up files and directories by encrypting
tar-format volumes with GnuPG and uploading them to a remote (or local)
file server. In theory many remote backends are possible; right now
local, ssh/scp, ftp, rsync, HSI, WebDAV, and Amazon S3 backends are
written.

Because duplicity uses librsync, the incremental archives are space
efficient and only record the parts of files that have changed since
the last backup. Currently duplicity supports deleted files, full unix
permissions, directories, symbolic links, fifos, etc., but not hard
links.

%prep
%setup -q
%patch1 -p1

%build
python setup.py build

%install
python setup.py install --prefix=/usr --root=%{buildroot} --record-rpm=files.lst
rm -rf %{buildroot}%{_datadir}/doc/duplicity-%{version}
perl -n -i -e 'print unless m,(%{_bindir}|%{_mandir}|%{_datadir}/doc|%{_datadir}/locale|%{python_sitearch}/testing),' files.lst
%find_lang %{name}
cat %{name}.lang files.lst > rpmfiles.lst

%files -f rpmfiles.lst
%defattr(-,root,root)
%doc CHANGELOG COPYING README
%{_bindir}/duplicity
%{_bindir}/rdiffdir
%doc %{_mandir}/man1/duplicity.1%{ext_man}
%doc %{_mandir}/man1/rdiffdir.1%{ext_man}

%changelog
* Tue Aug 23 2016 wr@rosenauer.org
- update to 0.7.10
  * fixed several issues
  - Restore from S3 fails with --with-prefix-archive if prefix
    includes '/'
  * Changes for connecting to IBM Bluemix ObjectStorage. See man page
  * Allow duplicity to create remote folder
* Sat Aug  6 2016 wr@rosenauer.org
- update to 0.7.09
  * Fixed bug #1600692 with patch from Wolfgang Rohdewald
  - Allow symlink to have optional trailing slash during verify.
  * Merged in lp:~aaron-whitehouse/duplicity/07-fix_deja_dup_error_on_locked_files
  - Revert log.Error to log.Warn, as it was prior to the merge in rev 1224,
    as this was affecting other applications (e.g. deja dup; Bug #1605939).
  * Merged in lp:~duplicity-team/duplicity/po-updates
* Sun Jul 10 2016 wr@rosenauer.org
- update to 0.7.08
  * adds the ability to use path in the swift backend, in order to
    have multiple backups to the same container neatly organized.
  * Increased default volume size to 200M, was 25M
  * further bugfixes as outlined here
    http://duplicity.nongnu.org/CHANGELOG
* Wed Jun 15 2016 wr@rosenauer.org
- update to 0.7.07.1
  * upgrade dropbox backend: update to SDK v2, use chunked upload
  * added --ssl-cacert-path parameter
  * Backend for https://www.mediafire.com
    (Requires https://pypi.python.org/pypi/mediafire/ installed)
  * support GSSAPI authentication in webdav backend
  * further bugfixes as outlined here
    http://duplicity.nongnu.org/CHANGELOG
* Wed Dec  9 2015 wr@rosenauer.org
- update to 0.7.06
  * This adds support for AWS S3's newly announced Infrequent Access
    storage class and is intended to implement Blueprint:
    https://blueprints.launchpad.net/duplicity/+spec/aws-s3-std-ia-class
  * A new command line option, --s3-use-ia, is added, and boto backend
    will automatically use the correct storage class value depending on
    whether --s3-use-rrs and --s3-use-ia is set. Command line parser will
    prompt error if both --s3-use-ia and --s3-use-rrs are used together,
    as they conflict with each other.
  * Upgrade to newest version of pep8 and pylint
  * WindowsAzureMissingResourceError and WindowsAzureConflictError
    changed due to SDK changes.
  * make sure packages using python's tempfile create temp files in
    duplicity's temp dir
  * Fixed bug #1511308 - Cannot restore no-encryption, no-compression backup
  * Fix missing SWIFT_ENDPOINT_TYPE env var, bug #1519694.
  * Fix bug #1520691 - Shell Code Injection in hsi backend
  * Support new version of Azure Storage SDK
  * Adds a backend for BackBlaze's (currently beta) B2 backup service.
* Mon Nov 23 2015 wr@rosenauer.org
- current FTP default is lftp; therefore recommend that instead
  of ncftp
* Sat Sep 19 2015 wr@rosenauer.org
- update to 0.7.05
  * bugfix release
  * see details here
    http://duplicity.nongnu.org/CHANGELOG
* Tue Aug  4 2015 wr@rosenauer.org
- update to 0.7.04
  * bugfix release
  * see details here
    http://duplicity.nongnu.org/CHANGELOG
* Sat Mar 21 2015 wr@rosenauer.org
- update to 0.7.02
  * bugfix release
  * see details here
    http://duplicity.nongnu.org/CHANGELOG
- removed obsolete duplicity-librsync-1.0.patch
* Thu Mar  5 2015 dimstar@opensuse.org
- Add duplicity-librsync-1.0.patch: Fix build with librsync 1.0.0.
* Wed Feb 25 2015 tchvatal@suse.com
- Version bump to 0.7.01:
  http://duplicity.nongnu.org/CHANGELOG
- Clean-up with spec-cleaner
* Sun Nov  9 2014 wr@rosenauer.org
- Update to version 0.7.0
  * see details here
    http://duplicity.nongnu.org/CHANGELOG
- updated duplicity-remove_shebang.patch
* Wed Jul  9 2014 kruber@zib.de
- Update to version 0.6.24
  * lot of bugfixes
  * see details here
    http://duplicity.nongnu.org/CHANGELOG
- requires python-setuptools
* Sat Feb  1 2014 wr@rosenauer.org
- Update to version 0.6.23
  * lot of bugfixes
  * see details here
    http://duplicity.nongnu.org/CHANGELOG
- requires python-lockfile
* Sun Sep 15 2013 wr@rosenauer.org
- Update to version 0.6.22:
  * see details here
    http://duplicity.nongnu.org/CHANGELOG
    some highlights:
  - Add Dropbox backend
    Install Dropbox Python SDK first
  - Add support for Swift, the OpenStack Object Storage service
  - Add support for Google Cloud Storage via the boto backend
  - Add support for Mega (mega.co.nz) backend
* Thu Feb  7 2013 wr@rosenauer.org
- Update to version 0.6.21:
  * see details here
    http://duplicity.nongnu.org/CHANGELOG
    some highlights:
  - Allow .netrc auth for lftp backend
  - Generate encrypted backups without revealing the user's key id
    via option --hidden-encrypt-key
* Sat Nov 10 2012 wr@rosenauer.org
- Update to version 0.6.20:
  * several improvements and bugfixes
    http://duplicity.nongnu.org/CHANGELOG
* Mon Jun 18 2012 wr@rosenauer.org
- Update to version 0.6.19:
  * several bugfixes and ssh backends enhancements
* Mon Mar  5 2012 wr@rosenauer.org
- Update to version 0.6.18:
  * Added option to not compress the backup, when no encryption
    is selected
  * Adding --file-prefix option so different sets of backups can
    be stored in the same bucket
  * more bugfixes
* Mon Feb 20 2012 coolo@suse.com
- factory has split librsync into devel and lib package
* Wed Feb  8 2012 wr@rosenauer.org
- Update to version 0.6.17:
  * Added --rsync-options flag to allow user to pass options to
    rsync at will
  * Added --s3-use-multiprocessing to select the new s3
    multiprocessing backend.
    Default is to use the single processing backend.  A helper,
    filechunkio.py, requires Python 2.6+, so this option is not
    usable in earlier versions.
- Update to version 0.6.16:
  * Usability enhancement: sign passphrase prompt has no second
    verification prompt anymore, symmetric passphrases are
    still verified
  * Fixed Unicode errors when translations are used.
  * Replaced old tarfile.py with Python 2.7 version, modded
    to support Python 2.4 syntax.
* Sat Oct  1 2011 dimstar@opensuse.org
- Update to version 0.6.15:
  + Ignore 404 errors when deleting a file on Ubuntu One.
  + Ignore ENOENT (file missing) errors where it is safe.
  + Set minimum Python version to 2.4 in README.
  + introduce --numeric-owner parameter
  + duplicity:restore_check_hash "Invalid data - *** hash mismatch"
    lists the offending filename
  + fixes to unit tests to support SIGN_PASSPHRASE
  + Bugs fixed: lp#524922, lp#703142, lp#794576, lp#815635,
    lp#818178, lp#821368, lp#823556, lp#824678
- Changes from version 0.6.14:
  + Provide Ubuntu One integration
  + Bugs fixed: lp#433591, lp#487720, lp#507904, lp#512628,
    lp#680425, lp#705499, lp#739438, lp#753858, lp#761688,
    lp#777377, lp#778215, lp#782294, lp#782321, lp#792704,
    lp#782294, lp#782337, lp#794123, lp#797758, lp#793096.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Mon Jun 20 2011 wr@rosenauer.org
- update to 0.6.13
  fixed bugs:
  * Assertion error "time not moving forward at appropriate pace"
  * silent data corruption with checkpoint/restore
  * File "/usr/bin/duplicity", error after upgrade from 6.11 to 6.12
  features:
  * In boto backend check for existing bucket before trying to create
- update to 0.6.12
  fixed bugs:
  * Only full backups done on webdav
  * Use log codes for common backend errors
  * Inverted "Current directory" "Previous directory" in error message
  * OSError: [Errno 2] No such file or directory
  * sslerror: The read operation timed out with cf
  * boto backend uses Python 2.5 conditional
  * symbolic link ownership not preserved
  * Cygwin: TypeError: basis_file must be a (true) file
  * Duplicity 0.6.11 aborts if RSYNC_RSH not set
  * Backup fails silently when target is full (sftp, verbosity=4)
  * Exception in log module
  features:
  * ftps support using lftp (ftpsbackend)
* Sat Jan  1 2011 wr@rosenauer.org
- update to 0.6.11
  * Add an option to connect to S3 with regular HTTP (and not HTTPS)
  * Use log codes for common backend errors
  * missing ssh on rsyncd url - rsync: Failed to exec ssh: ...
  * backed up to S3, wiped drive, reinstalled, unable to restore backup
  * os.execve should get passed program as first argument
  * sftp: "Couldn't delete file: Failure'" only logged on level 9
  * 0.6.10 does not work with S3
  * RsyncBackend instance has no attribute 'subprocess_popen_persist'
* Tue Sep 28 2010 wr@rosenauer.org
- update to 0.6.10
  - changes in 0.6.10
  * Offer command to remove old incremental backups from target
  * Use log codes for common backend errors
  * duplicity --short-filenames crashes with TypeError
  * NameError: global name 'parsed_url' is not defined
  * ftpbackend fails if target directory doesn't exist
  * Command-line verbosity parsing crash
  - changes in 0.6.9
  * Unknown error while uploading duplicity-full-signatures
  * Duplicity returns 1 when continuing an interrupted backup
  * duplicity doesn't handle with large files well
  * --ssh-options options passing options to ssh do not work
  * username not url decoded in backend (at least rsync)
  * Assertion error "time not moving forward at appropriate pace"
  * Diminishing performance on large files
  * Upgraded tahoebackend to new parse_url.
  * Fix two warning messages in sshbackend.
- GnuPGInterface and pexpect are part of duplicity
  - > removed RPM requirements
- Require ncftp
- Recommend (optional components depending on which backup medium
  should be used)
  * ncftp
  * python-boto (optional requirement for use with S3; module not
    in Factory yet though)
* Mon Mar 15 2010 pascal.bleser@opensuse.org
- update to 0.6.08b:
  * fix bug where encrypted backup without --gpg-options crashes;
- changes from 0.6.08:
  * fix lp#519110: need accurate man page info on use of scp/sftp usage
  * fix lp#532051: rdiffdir attempts to reference undefined variables with
    some command arguments
  * fix lp#529869: TypeError: unsupported operand type(s) for -:
    'NoneType' and 'int'
  * fix lp#530910: TypeError: unsupported operand type(s) for +:
    'NoneType' and 'str'
- changes from 0.6.07:
  * fix lp#459511: --tempdir option doesn't override TMPDIR
  * fix lp#467391: WebDAV backend doesn't work
  * fix lp#487686: re-add scp backend and make available via command line option
  * fix lp#490619: use optparse not getopt
  * fix lp#497243: 0.6.06, archive dir: cache desynchronization caused by remove*
  * fix lp#501093: SSHBackend doesn't handle spaces in path
  * fix lp#505739: "sslerror: The read operation timed out" with S3
  * fix lp#520470: don't warn when there's old backup to delete
  * fix lp#522544: OSError: [Errno 40] Too many levels of symbolic links
  * fix lp#388673: allow renaming paths as they are restored
* Mon Feb  8 2010 rhafer@novell.com
- Update to version 0.6.06:
  * Merged in lp:~mterry/duplicity/list-old-chains
    List/keep old signature chains
  * Applied patches from Kasper Brand that fixed device file handling.
  * Applied 422477; [PATCH] IMAP Backend Error in delete()
  * Merged in lp:~mterry/duplicity/iterate-warnings Add machine
    codes to various warnings when iterating over source files
  * Fixed 435975 gpg asks for password in 0.6.05, but not in 0.5.18
- Bugs fixed in v0.6.05 (2009/08/28)
  * 407968: GIO backend can't restore
  * 408059: Failure due to _logger.log failure for content with special
    characters: TypeError decoding Unicode not supported
  * 409593: deja-dup (or duplicity) deletes all signatures
  * 412667: "duplicity remove-older-than" asks for passphrase even though
    not required
  * 418170: [PATCH] file names longer then 512 symbols are not supported
- Bugs fixed in v0.6.04
  * 405734: duplicity fails to restore files that contain a newline character
  * 403790: Backup error: No such file or directory
- Bugs fixed in v0.6.03
  * 377528: --file-to-restore doesn't work with trailing slash
  * 394757: Backend imports should be made optional
  * 398230: Deja-dup backup fails with message: "Unable to locate last file"
  * 401303: 0.6.2 manpage inconsistent wrt. archive-dir/name
  * 405646: Small i18n error
  * 405975: duplicity.gpg.gpg_failed() breaks and spews on GnuPG error
  * 402794: duplicity public-key-only incompatible with gnupg 2.0.11
- Bugs fixed in v0.6.02
  * 394629: Hang on first collection-status
  * 379386: Fix 'list-current-files' with missing archive dir
  * 395826: "No such file or directory" when backing up second time
  * 394627: User-friendly archive dir print
  * 388699: Manifest mismatch error
- Bugs fixed in v0.6.01
  * 388034: Unable to backup
  * 378940: python2-6 issue / UTF-8 charset / Ubuntu 9.04
  * 379386: Fix list-current-files w/ missing archive dir
  * 387102: Asynchronous upload not working properly
  * 387218: Make scp/ssh into sftp-only backend
  * 388992: List of Orphaned Files Growing
  * 392905: NoneType object has no attribute 'startswith'
  * 393372: Error creating directory
  * 383412: Add InfoCodes for upload events
  * 383419: Add gio backend
- For older changes please see
  /usr/share/doc/packages/duplicity/CHANGELOG
  or http://duplicity.nongnu.org/CHANGELOG
* Fri Aug 29 2008 jfunk@funktronics.ca
- Apply fix for http://savannah.nongnu.org/bugs/?23985
  - -no-encryption option does no more work with duplicity 0.4.12
* Thu Jul 24 2008 cthiel@suse.de
- update to version 0.4.12
  * Dan Muresan created a patch to minimize the number of password
    prompts.  To do so, it sometimes requests a password once without
    confirmation; if later it turns out that a full backup is needed,
    the user is prompted for confirmation.
  * bug #23540: doc bug in man page (environment FTP_PASSWORD)
    https://savannah.nongnu.org/bugs/index.php?23540
  * bug #23362: Documentation for --version, --time-separator <char>
    https://savannah.nongnu.org/bugs/index.php?23362
  * bug #23283: interactive passphrase query is suboptimal
    https://savannah.nongnu.org/bugs/index.php?23283
  * bug #23066 was not actually applied to 0.4.11.  Its here now.
    https://savannah.nongnu.org/bugs/index.php?23066
  * bug #22826: regressions caused by boto 1.1c
  * https://savannah.nongnu.org/bugs/index.php?22826
- changes in 0.4.11
  * Changes applied to allow duplicity to run under Python 2.3 again.
  * patch #6485: Reinstate patch #6340 with a detailed explanation.
  https://savannah.nongnu.org/patch/index.php?6485
  * bug #23066: ssh uris with given portnumbers are not handled correctly
    https://savannah.nongnu.org/bugs/index.php?23066
* Thu Apr 17 2008 cthiel@suse.de
- update to version 0.4.10
  * bug #22728: FTP backend fails on empty directory
  * patch #6374: Duplicity --tempdir patch documentation.
  * patch #6375: Duplicity reports the epoch for a nonexistant last full
    backup date
  * patch #6380: add additional named logging levels
  * patch #6389: Possible Fix for pagefile.sys on Win32 systems
  * patch #6403: Restore by overwriting files/directories by using --force
    option
  * patch #6449: add additional debug level logging
  * patch #6453: handle absolute urls in webdav backend
  * Fix problem where S3 prefix was prepended with 'd'.  This caused a
    failure in the regression tests.
- changes in version 0.4.9
  * NOTE: URL format correction in rsync://.  The rsync backend
    now properly supports absolute and relative pathnames and
    module access.  The formats are:
    rsync://user@host::/module/some_dir
    rsync://user@host/relative_path
    rsync://user@host//absolute_path
  * Fixed regression caused by changeover to new urlparse.py.
  * bug #21475: FTP Usernames that contain '@' are not recognized
  * Added section URL FORMAT in the duplicity man page.
  * Added 2nd patch to bug #21475 that forces all versions of
    Python to use the fixed urlparse.py.
  * Fixed so that remove-older-than and remove-all-but-n-full
    will not request a GPG passphrase.
  * Fixed issue with Pure-FTPd that would always return an empty directory
    listing and thus force a full backup every time.  A side effect of the
    change is that we now only make one call to ncftpls to get the listing,
    thereby reducing the overhead on systems with a large number of backup
    files.
  * bug #21896: Two problems with rsync under 0.4.8 + patch
  * bug #21909: Problematic typo in compare_verbose() method
  * patch #6354: S3 staight typo results in a bogus exception
  * patch #6356: Command line option for the temporary directory root.
  * patch #6357: Explicit restore action is missing from the command list,
- changes in version 0.4.8
  * First pass at bringing unittest cases up to date.  All unit tests are
    working, but more test cases need to be added to handle the new
    protocols, plus there is some print leakage even with logging turned
    off.
  * Allow pexpect to force the close of the child on sftp calls.  We already
    do that with scp calls.  This cleans up that exception.
  * bug #21751: rsync module urls do not work in 0.4.7
  * bug #21752: Boto backend needs version 0.9d or later
  * patch #6340: S3 short filename regression
  * patch #6344: S3 bad bad key key handling
- changes in version 0.4.7
  * Applied patch from Eric Hanchrow to fix logging error in botoBackend,
    and fix delete() in rsyncBackend.
  * bug #21673: remove-all-but-n-full wrong arg usage
  * bug #21686: NcFTPGet 3.2.0 tempfile incompatibility
  * patch #6292: Amazon S3 bucket creation deferral
  * patch #6293: left-over patch from remove-all-but-n-full
  * patch #6296: Generic S3 url support for Duplicity 0.4.6
  * patch #6298: URI unquoting patch for FTP backend
  * patch #6299: re-design tempfile handling
  * patch #6300: Standard library replacement for ParsedUrl class
  * patch #6301: log sftp commands at verbosity 5
* Tue Dec  4 2007 cthiel@suse.de
- update to version 0.4.6
  * https://savannah.nongnu.org/bugs/index.php?21508
    bug #21508: Change delete implementation of ftpBackend to
    only send one "DELE" instead of multiple per delete.
  * https://savannah.nongnu.org/bugs/index.php?21646
    bug #21646: --archive-dir causes delete of remote full
    sigs and orphaned sig files
  * https://savannah.nongnu.org/bugs/index.php?21651
    bug #21651, add https support for webdav.
  * https://savannah.nongnu.org/bugs/index.php?21657
    bug #21657: ncftpls fails to create dir in ver 0.4.5
  * https://savannah.nongnu.org/patch/?6284
    patch #6284: document TMPDIR and friends
  * https://savannah.nongnu.org/patch/?6284
    patch #6285: security fix: eliminate use of mktemp()
  * https://savannah.nongnu.org/patch/index.php?6289
    patch #6289: Amazon S3 key prefix patch for Duplicity 0.4.5
  * https://savannah.nongnu.org/patch/index.php?6291
    patch #6291: Alternative WebDAV HTTPS patch
- changes in 0.4.5
  * https://savannah.nongnu.org/bugs/index.php?21646
    Fix to handling of collections when --archive-dir is used.  Prior to
    this, duplicity would write the full sig files to both local and remote,
    then delete the remote.  Now, it does not delete the remote full sigs.
  * Applied the following patches from Peter Schuller
    patch #6279, add command 'remove-all-but-n-full'
    patch #6280, clarify --archive-dir option
    patch #6281, --help should print to stdout, not stderr
    patch #6282, collection-status: output in more consistent order
- changes in 0.4.4
  * Changes to ftpBackend to use a temp login config file rather than
    putting the username and password on the command line.  This requires
    the use of NcFTP 3.1.9 or later.
  * Thanks to a patch from Greg Hewgill the Amazon S3 backend now uses
  - -num-retries to retry IO repeatedly if needed.
  * Changes to commandline processing to allow non-ambiguous short strings
    for commands, i.e. 'i', 'inc', 'incr' for 'incremental', 'f' for 'full',
    etc..  A warning message is printed if the short command is not unique.
    Note: this already works for options, so I just applied the same idea to
    commands.
  * Applied a patch from Gregory Hartman to correct handling of DST
    in time calculations.  This affects backups made the night of
    a DST time switch.
* Sun Oct  7 2007 cthiel@suse.de
- update to version 0.4.3
  * Move get_password() to Backend class to standardize.
  * Fix problem with ftpBackend to create target directory if needed.  Note:
    this creates only one level.
  * Dropped ssh-command and added ssh-options to allow users to add options
    to the scp and sftp commmands.
  * Removed use of tempfile.TemporaryFile().  This fixes the restore problem
    on Windows that was due to Python bug 1776696 reported on Sourceforge.
  * Fixed Debian Bug#437694: Make bzip2 compression optional.  The default
    is not to do bzip2 compression.  To use bzip2 add the following command
    line option: --gpg-options='--compress-algo=bzip2
  - -bzip2-compress-level=9' Note: do not add spaces in the string value.
  * Fixed bug 20764 - unable to use port in ssh backend.
    https://savannah.nongnu.org/bugs/?20764
  * Remove ssh_command option, add ssh_options.  This adds options to the
    scp and sftp commands that are used by the ssh backend.
  * Change ssh backend to send 'quit' instead of EOF when using sftp.  This
    allows it to run under cron as long as the password is supplied
    non-interactively.
  * Change ssh backend to not pass :port part of URL to scp or sftp.  We
    already supply -oPort=xx for port.
* Mon May 14 2007 cthiel@suse.de
- initial package (version 0.4.2)
